summaryrefslogtreecommitdiffstats
path: root/kexi/widget/kexieditor.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/widget/kexieditor.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/widget/kexieditor.h')
-rw-r--r--kexi/widget/kexieditor.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kexi/widget/kexieditor.h b/kexi/widget/kexieditor.h
index fce5f45b..022b0dd9 100644
--- a/kexi/widget/kexieditor.h
+++ b/kexi/widget/kexieditor.h
@@ -22,7 +22,7 @@
#ifndef KEXIEDITOR_H
#define KEXIEDITOR_H
-#include <qwidget.h>
+#include <tqwidget.h>
#include "kexiviewbase.h"
class KTextEdit;
@@ -39,6 +39,7 @@ namespace KTextEditor
class KEXIEXTWIDGETS_EXPORT KexiEditor : public KexiViewBase
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -47,12 +48,12 @@ class KEXIEXTWIDGETS_EXPORT KexiEditor : public KexiViewBase
*
* \param mainWin The \a KexiMainWindow instance this KexiEditor
* belongs too.
* \param parent The parent \a QWidget this KexiEditor is child
* of. You don't need to free the KexiEditor cause Qt
* will handle that for us.
* \param name The name this KexiEditor has. Used only for debugging.
*/
- KexiEditor(KexiMainWindow *mainWin, QWidget *parent, const char *name = 0);
+ KexiEditor(KexiMainWindow *mainWin, TQWidget *tqparent, const char *name = 0);
/**
* Destructor.
@@ -68,7 +69,7 @@ class KEXIEXTWIDGETS_EXPORT KexiEditor : public KexiViewBase
/**
* \return the text displayed in the editor-widget.
*/
- QString text();
+ TQString text();
/**
* Set the highlight-mode to \p highlightmodename . If
@@ -78,7 +79,7 @@ class KEXIEXTWIDGETS_EXPORT KexiEditor : public KexiViewBase
* of string like e.g. "python", "kjs" or "sql"
* KTextEditor supports.
*/
- void setHighlightMode(const QString& highlightmodename);
+ void setHighlightMode(const TQString& highlightmodename);
/**
* Find row and column for this \p character and jump to the
@@ -100,7 +101,7 @@ class KEXIEXTWIDGETS_EXPORT KexiEditor : public KexiViewBase
public slots:
/*! Sets editor's text to \a text. 'Dirty' flag remains unchanged.
Undo/redo buffer is cleared.*/
- void setText(const QString &text);
+ void setText(const TQString &text);
/*! Display the configuration-dialog. Only avaiable if isAdvancedEditor() returns true. */
void slotConfigureEditor();
@@ -47,12 +48,12 @@ class KEXIEXTWIDGETS_EXPORT KexiEditor : public KexiViewBase
* \param mainWin The \a KexiMainWindow instance this KexiEditor
* belongs too.
- * \param parent The parent \a QWidget this KexiEditor is child
- * of. You don't need to free the KexiEditor cause Qt
+ * \param tqparent The tqparent \a TQWidget this KexiEditor is child
+ * of. You don't need to free the KexiEditor cause TQt
* will handle that for us.
* \param name The name this KexiEditor has. Used only for debugging.